@@ -11,8 +11,8 @@ NULL
 #'  used (see [colour()]).
 #' @param reverse A [`logical`] scalar: should the resulting vector of colors
 #'  should be reversed?
-#' @param label A [`logical`] scalar: should the names of the colors should be
-#'  kept in the resulting vector?
+#' @param use_names A [`logical`] scalar: should the names of the colors be
+#'  preserved?
 #' @param lang A [`character`] string specifying the language for the color
 #'  names. It must be one of "`en`" (english, the default) or "`fr`" (french).
 #' @param type A [`character`] string specifying the scale to be
@@ -33,9 +33,13 @@ NULL
 NULL
 
 scale_discrete <- function(aesthetics, scale_name, reverse = FALSE,
-                           labels = FALSE, lang = "en", ...) {
+                           use_names = FALSE, lang = "en", ...) {
+  # Check if ggplot2 is installed
+  check_package("ggplot2")
+
   # Get colour scheme
-  palette <- colour(scale_name, reverse = reverse, names = labels, lang = lang)
+  palette <- colour(scale_name, reverse = reverse, names = use_names,
+                    lang = lang)
 
   # Build scale
   scale_arguments <- list(...)
@@ -50,6 +54,9 @@ scale_discrete <- function(aesthetics, scale_name, reverse = FALSE,
 
 scale_continuous <- function(aesthetics, scale_name, reverse = FALSE,
                              lang = "en", range = c(0, 1), midpoint = 0, ...) {
+  # Validation
+  check_package("ggplot2") # Check if ggplot2 is installed
+
   # Get colour scheme
   palette <- colour(scale_name, reverse = reverse, names = FALSE, lang = lang)
   max <- attr(palette, "max")
@@ -78,6 +85,7 @@ scale_continuous <- function(aesthetics, scale_name, reverse = FALSE,
 #' @keywords internal
 #' @noRd
 mid_rescaler <- function(mid) {
+  check_package("scales") # Check if scales is installed
   function(x, to = c(0, 1), from = range(x, na.rm = TRUE)) {
     scales::rescale_mid(x, to, from, mid)
   }
