@@ -1,3 +1,6 @@
+plot(colour("bright")(7))
+plot(colour("smooth rainbow")(256))
+
 ## Plot colour schemes
 plot_scheme(colour("bright")(7))
 plot_scheme(colour("sunset")(11))
@@ -9,3 +12,6 @@ plot_map(colour("bright")(7))
 plot_map(colour("sunset")(11))
 plot_map(colour("YlOrBr")(9))
 plot_map(colour("discrete rainbow")(14))
+
+## Plot simulated color blindness
+plot_scheme_colorblind(colour("bright")(7))
