@@ -1,10 +1,12 @@
-test_that("ggplo2 rescaler", {
+test_that("ggplot2 rescaler", {
   skip_if_not_installed("scales")
   expect_type(mid_rescaler(mid = 5)(1:100), "double")
   expect_length(mid_rescaler(mid = 5)(1:100), 100)
   expect_equal(max(mid_rescaler(mid = 5)(1:100)), 1)
 })
-
+test_that("Palette informations", {
+  expect_snapshot(info(), cran = TRUE)
+})
 test_that("Palette colours", {
   palettes <- c("okabe ito", "bright", "contrast", "vibrant", "muted", "pale",
                 "dark", "light", "sunset", "BuRd", "PRGn", "YlOrBr",
@@ -119,9 +121,11 @@ test_that("Colour-blind attributes", {
   expect_true(attr(protanopia, "mode") == "protanopia")
 })
 test_that("Print with crayon", {
+  skip_if_not_installed("crayon")
+  options(crayon.enabled = FALSE)
+
   palette <- colour("okabe ito")
 
-  options(crayon.enabled = FALSE)
   col <- utils::capture.output(print(palette(8)))
   expect_type(col, "character")
 
